@@ -122,6 +122,17 @@ public interface ImageTransfer extends Identified {
      */
     Integer inactivityTimeout();
 
+    /**
+     * Timeout policy determines how the system handles the transfer when a client is idle
+     * for more than inactivityTimeout.
+     *
+     * @author Ahmad Khiet <akhiet@redhat.com>
+     * @date 21 Jan 2021
+     * @status added
+     * @since 4.4.5
+     */
+    ImageTransferTimeoutPolicy timeoutPolicy();
+
     /**
      * The image which is targeted for input or output.
      *
