@@ -734,6 +734,52 @@ public interface VmService extends MeasurableService {
         }
     }
 
+    /**
+     * Apply an automatic CPU and NUMA configuration on the VM.
+     *
+     * An example for a request:
+     * [source]
+     * ----
+     * POST /ovirt-engine/api/vms/123/autopincpuandnumanodes
+     * ----
+     *
+     * With a request body like this:
+     *
+     * [source,xml]
+     * ----
+     * <action>
+     *   <optimize_cpu_settings>true</optimize_cpu_settings>
+     * </action>
+     * ----
+     *
+     * @author Liran Rotenberg <lrotenbe@redhat.com>
+     * @date 20 Jan 2021
+     * @status added
+     * @since 4.4.5
+     */
+    interface AutoPinCpuAndNumaNodes {
+        /**
+         * Specifies how the auto CPU and NUMA configuration is applied.
+         * If set to true, will adjust the CPU topology to fit the VM pinned host hardware.
+         * Otherwise, it will use the VM CPU topology.
+         *
+         * @author Liran Rotenberg <lrotenbe@redhat.com>
+         * @date 20 Jan 2021
+         * @status added
+         * @since 4.4.5
+         */
+        @In Boolean optimizeCpuSettings();
+
+        /**
+         * Indicates if the detach action should be performed asynchronously.
+         *
+         * @author Megan Lewis <melewis@redhat.com>
+         * @date 28 Mar 2017
+         * @status updated_by_docs
+         */
+        @In Boolean async();
+    }
+
     /**
      * Update the virtual machine in the system for the given virtual machine id.
      *
@@ -841,6 +887,7 @@ public interface VmService extends MeasurableService {
             optional(vm().payloads()[COLLECTION].volumeId());
             optional(vm().storageErrorResumeBehaviour());
             optional(vm().multiQueuesEnabled());
+            optional(vm().virtioScsiMultiQueuesEnabled());
         }
     }
 
@@ -862,12 +909,44 @@ public interface VmService extends MeasurableService {
      * <action/>
      * ----
      *
+     * To reboot the VM even if a backup is running for it,
+     * the action should include the 'force' element.
+     *
+     * For example, to force reboot virtual machine `123`:
+     *
+     * ----
+     * POST /ovirt-engine/api/vms/123/reboot
+     * ----
+     *
+     * [source,xml]
+     * ----
+     * <action>
+     *     <force>true</force>
+     * </action>
+     * ----
+     *
      * @author Martin Betak <mbetak@redhat.com>
      * @author Megan Lewis <melewis@redhat.com>
-     * @date 28 Mar 2017
-     * @status updated_by_docs
+     * @author Eyal Shenitzky <eshenitz@redhat.com>
+     * @date 4 Jan 2021
+     * @status added
      */
     interface Reboot {
+        @InputDetail
+        default void inputDetail() {
+            optional(force());
+        }
+
+        /**
+         * Indicates if the VM should be forcibly rebooted even
+         * if a backup is running for it.
+         *
+         * @author Eyal Shenitzky <eshenitz@redhat.com>
+         * @date 31 Dec 2020
+         * @status added
+         */
+        @In Boolean force();
+
         /**
          * Indicates if the reboot should be performed asynchronously.
          *
@@ -952,12 +1031,44 @@ public interface VmService extends MeasurableService {
      * <action/>
      * ----
      *
+     * To shutdown the VM even if a backup is running for it,
+     * the action should include the 'force' element.
+     *
+     * For example, to force shutdown virtual machine `123`:
+     *
+     * ----
+     * POST /ovirt-engine/api/vms/123/shutdown
+     * ----
+     *
+     * [source,xml]
+     * ----
+     * <action>
+     *     <force>true</force>
+     * </action>
+     * ----
+     *
      * @author Arik Hadas <ahadas@redhat.com>
      * @author Megan Lewis <melewis@redhat.com>
-     * @date 28 Mar 2017
-     * @status updated_by_docs
+     * @author Eyal Shenitzky <eshenitz@redhat.com>
+     * @date 4 Jan 2021
+     * @status added
      */
     interface Shutdown {
+        @InputDetail
+        default void inputDetail() {
+            optional(force());
+        }
+
+        /**
+         * Indicates if the VM should be forcibly shutdown even
+         * if a backup is running for it.
+         *
+         * @author Eyal Shenitzky <eshenitz@redhat.com>
+         * @date 31 Dec 2020
+         * @status added
+         */
+        @In Boolean force();
+
         /**
          * Indicates if the shutdown should be performed asynchronously.
          *
@@ -1206,12 +1317,43 @@ public interface VmService extends MeasurableService {
      * <action/>
      * ----
      *
+     * To stop the VM even if a backup is running for it,
+     * the action should include the 'force' element.
+     *
+     * For example, to force stop virtual machine `123`:
+     *
+     * ----
+     * POST /ovirt-engine/api/vms/123/stop
+     * ----
+     *
+     * [source,xml]
+     * ----
+     * <action>
+     *     <force>true</force>
+     * </action>
+     * ----
+     *
      * @author Arik Hadas <ahadas@redhat.com>
      * @author Megan Lewis <melewis@redhat.com>
-     * @date 28 Mar 2017
-     * @status updated_by_docs
+     * @author Eyal Shenitzky <eshenitz@redhat.com>
+     * @date 4 Jan 2021
+     * @status added
      */
     interface Stop {
+        @InputDetail
+        default void inputDetail() {
+            optional(force());
+        }
+
+        /**
+         * Indicates if the VM should be forcibly stop even
+         * if a backup is running for it.
+         * @author Eyal Shenitzky <eshenitz@redhat.com>
+         * @date 31 Dec 2020
+         * @status added
+         */
+        @In Boolean force();
+
         /**
          * Indicates if the stop action should be performed asynchronously.
          *
