@@ -17,7 +17,9 @@ limitations under the License.
 package services.gluster;
 
 import annotations.Area;
+import mixins.Follow;
 import org.ovirt.api.metamodel.annotations.In;
+import org.ovirt.api.metamodel.annotations.InputDetail;
 import org.ovirt.api.metamodel.annotations.Out;
 import org.ovirt.api.metamodel.annotations.Service;
 import services.MeasurableService;
@@ -25,6 +27,9 @@ import types.GlusterVolume;
 import types.GlusterVolumeProfileDetails;
 import types.Option;
 
+import static org.ovirt.api.metamodel.language.ApiLanguage.mandatory;
+import static org.ovirt.api.metamodel.language.ApiLanguage.optional;
+
 /**
  * This service manages a single gluster volume.
  *
@@ -83,7 +88,7 @@ public interface GlusterVolumeService extends MeasurableService {
      * @date 12 Dec 2016
      * @status added
      */
-    interface Get {
+    interface Get extends Follow {
         /**
          * Representation of the gluster volume.
          *
@@ -140,6 +145,11 @@ public interface GlusterVolumeService extends MeasurableService {
      * @status added
      */
     interface Rebalance {
+        @InputDetail
+        default void inputDetail() {
+            optional(fixLayout());
+            optional(force());
+        }
         /**
          * If set to true, rebalance will only fix the layout so that new data added to the volume is distributed
          * across all the hosts. But it will not migrate/rebalance the existing data. Default is `false`.
@@ -235,6 +245,11 @@ public interface GlusterVolumeService extends MeasurableService {
      * @status added
      */
     interface ResetOption {
+        @InputDetail
+        default void inputDetail() {
+            mandatory(force());
+            mandatory(option().name());
+        }
         @In Boolean force();
 
         /**
@@ -277,6 +292,11 @@ public interface GlusterVolumeService extends MeasurableService {
      * @status added
      */
     interface SetOption {
+        @InputDetail
+        default void inputDetail() {
+            mandatory(option().name());
+            mandatory(option().value());
+        }
         /**
          * Option to set.
          *
@@ -308,6 +328,10 @@ public interface GlusterVolumeService extends MeasurableService {
      * @status added
      */
     interface Start {
+        @InputDetail
+        default void inputDetail() {
+            optional(force());
+        }
         /**
          * Indicates if the volume should be force started. If a gluster volume is started already but few/all bricks
          * are down then force start can be used to bring all the bricks up. Default is `false`.
@@ -362,6 +386,10 @@ public interface GlusterVolumeService extends MeasurableService {
      * @status added
      */
     interface Stop {
+        @InputDetail
+        default void inputDetail() {
+            optional(force());
+        }
         @In Boolean force();
 
         /**
