@@ -101,6 +101,7 @@ public class VmBaseBuilder {
     private VmType type;
     private Usb usb;
     private VirtioScsi virtioScsi;
+    private Boolean virtioScsiMultiQueuesEnabled;
     
     public VmBaseBuilder bios(Bios newBios) {
         bios = newBios;
@@ -798,6 +799,17 @@ public class VmBaseBuilder {
     }
     
     
+    public VmBaseBuilder virtioScsiMultiQueuesEnabled(boolean newVirtioScsiMultiQueuesEnabled) {
+        virtioScsiMultiQueuesEnabled = Boolean.valueOf(newVirtioScsiMultiQueuesEnabled);
+        return this;
+    }
+    
+    public VmBaseBuilder virtioScsiMultiQueuesEnabled(Boolean newVirtioScsiMultiQueuesEnabled) {
+        virtioScsiMultiQueuesEnabled = newVirtioScsiMultiQueuesEnabled;
+        return this;
+    }
+    
+    
     public VmBase build() {
         VmBaseContainer container = new VmBaseContainer();
         container.bios(bios);
@@ -847,6 +859,7 @@ public class VmBaseBuilder {
         container.type(type);
         container.usb(usb);
         container.virtioScsi(virtioScsi);
+        container.virtioScsiMultiQueuesEnabled(virtioScsiMultiQueuesEnabled);
         return container;
     }
 }
