@@ -215,6 +215,9 @@ public class XmlActionReader {
                 case "name":
                 object.name(reader.readString());
                 break;
+                case "optimize_cpu_settings":
+                object.optimizeCpuSettings(reader.readBoolean());
+                break;
                 case "option":
                 object.option(XmlOptionReader.readOne(reader));
                 break;
