@@ -70,6 +70,9 @@ public class XmlDiskReader {
                 case "backup":
                 object.backup(XmlDiskBackupReader.readOne(reader));
                 break;
+                case "backup_mode":
+                object.backupMode(XmlDiskBackupModeReader.readOne(reader));
+                break;
                 case "bootable":
                 object.bootable(reader.readBoolean());
                 break;
@@ -85,6 +88,12 @@ public class XmlDiskReader {
                 case "disk_profile":
                 object.diskProfile(XmlDiskProfileReader.readOne(reader));
                 break;
+                case "disk_snapshots":
+                object.diskSnapshots(XmlDiskSnapshotReader.readMany(reader));
+                break;
+                case "external_disk":
+                object.externalDisk(reader.readString());
+                break;
                 case "format":
                 object.format(XmlDiskFormatReader.readOne(reader));
                 break;
@@ -253,6 +262,11 @@ public class XmlDiskReader {
         String href = link[1];
         if (href != null) {
             switch (rel) {
+                case "disksnapshots":
+                list = new ArrayListWithHref(object.diskSnapshots());
+                list.href(href);
+                object.diskSnapshots(list);
+                break;
                 case "permissions":
                 list = new ArrayListWithHref(object.permissions());
                 list.href(href);
