@@ -144,6 +144,9 @@ public class XmlHostWriter {
         if (object.protocolPresent()) {
             XmlHostProtocolWriter.writeOne(object.protocol(), "protocol", writer);
         }
+        if (object.reinstallationRequiredPresent()) {
+            writer.writeBoolean("reinstallation_required", object.reinstallationRequired());
+        }
         if (object.rootPasswordPresent()) {
             writer.writeElement("root_password", object.rootPassword());
         }
