@@ -133,6 +133,9 @@ public class XmlVmBaseReader {
                 case "migration_downtime":
                 object.migrationDowntime(reader.readInteger());
                 break;
+                case "multi_queues_enabled":
+                object.multiQueuesEnabled(reader.readBoolean());
+                break;
                 case "name":
                 object.name(reader.readString());
                 break;
@@ -190,6 +193,9 @@ public class XmlVmBaseReader {
                 case "virtio_scsi":
                 object.virtioScsi(XmlVirtioScsiReader.readOne(reader));
                 break;
+                case "virtio_scsi_multi_queues_enabled":
+                object.virtioScsiMultiQueuesEnabled(reader.readBoolean());
+                break;
                 case "link":
                 // Process the attributes:
                 String rel = reader.getAttributeValue("rel");
