@@ -35,6 +35,10 @@ public interface Ssh extends Identified {
     
     boolean portPresent();
     
+    String publicKey();
+    
+    boolean publicKeyPresent();
+    
     User user();
     
     boolean userPresent();
