@@ -23,6 +23,8 @@ import java.util.Collections;
 import java.util.List;
 import org.ovirt.engine.sdk4.internal.containers.DiskSnapshotContainer;
 import org.ovirt.engine.sdk4.types.Disk;
+import org.ovirt.engine.sdk4.types.DiskBackup;
+import org.ovirt.engine.sdk4.types.DiskBackupMode;
 import org.ovirt.engine.sdk4.types.DiskContentType;
 import org.ovirt.engine.sdk4.types.DiskFormat;
 import org.ovirt.engine.sdk4.types.DiskInterface;
@@ -47,12 +49,16 @@ public class DiskSnapshotBuilder {
     private Boolean active;
     private BigInteger actualSize;
     private String alias;
+    private DiskBackup backup;
+    private DiskBackupMode backupMode;
     private Boolean bootable;
     private String comment;
     private DiskContentType contentType;
     private String description;
     private Disk disk;
     private DiskProfile diskProfile;
+    private List<DiskSnapshot> diskSnapshots;
+    private String externalDisk;
     private DiskFormat format;
     private String href;
     private String id;
@@ -64,6 +70,7 @@ public class DiskSnapshotBuilder {
     private HostStorage lunStorage;
     private String name;
     private OpenStackVolumeType openstackVolumeType;
+    private DiskSnapshot parent;
     private List<Permission> permissions;
     private Boolean propagateErrors;
     private BigInteger provisionedSize;
@@ -139,6 +146,18 @@ public class DiskSnapshotBuilder {
     }
     
     
+    public DiskSnapshotBuilder backup(DiskBackup newBackup) {
+        backup = newBackup;
+        return this;
+    }
+    
+    
+    public DiskSnapshotBuilder backupMode(DiskBackupMode newBackupMode) {
+        backupMode = newBackupMode;
+        return this;
+    }
+    
+    
     public DiskSnapshotBuilder bootable(boolean newBootable) {
         bootable = Boolean.valueOf(newBootable);
         return this;
@@ -200,6 +219,47 @@ public class DiskSnapshotBuilder {
     }
     
     
+    public DiskSnapshotBuilder diskSnapshots(List<DiskSnapshot> newDiskSnapshots) {
+        if (newDiskSnapshots != null) {
+            if (diskSnapshots == null) {
+                diskSnapshots = new ArrayList<>(newDiskSnapshots);
+            }
+            else {
+                diskSnapshots.addAll(newDiskSnapshots);
+            }
+        }
+        return this;
+    }
+    
+    public DiskSnapshotBuilder diskSnapshots(DiskSnapshot... newDiskSnapshots) {
+        if (newDiskSnapshots != null) {
+            if (diskSnapshots == null) {
+                diskSnapshots = new ArrayList<>(newDiskSnapshots.length);
+            }
+            Collections.addAll(diskSnapshots, newDiskSnapshots);
+        }
+        return this;
+    }
+    
+    public DiskSnapshotBuilder diskSnapshots(DiskSnapshotBuilder... newDiskSnapshots) {
+        if (newDiskSnapshots != null) {
+            if (diskSnapshots == null) {
+                diskSnapshots = new ArrayList<>(newDiskSnapshots.length);
+            }
+            for (DiskSnapshotBuilder builder : newDiskSnapshots) {
+                diskSnapshots.add(builder.build());
+            }
+        }
+        return this;
+    }
+    
+    
+    public DiskSnapshotBuilder externalDisk(String newExternalDisk) {
+        externalDisk = newExternalDisk;
+        return this;
+    }
+    
+    
     public DiskSnapshotBuilder format(DiskFormat newFormat) {
         format = newFormat;
         return this;
@@ -326,6 +386,22 @@ public class DiskSnapshotBuilder {
     }
     
     
+    public DiskSnapshotBuilder parent(DiskSnapshot newParent) {
+        parent = newParent;
+        return this;
+    }
+    
+    public DiskSnapshotBuilder parent(DiskSnapshotBuilder newParent) {
+        if (newParent == null) {
+            parent = null;
+        }
+        else {
+            parent = newParent.build();
+        }
+        return this;
+    }
+    
+    
     public DiskSnapshotBuilder permissions(List<Permission> newPermissions) {
         if (newPermissions != null) {
             if (permissions == null) {
@@ -713,12 +789,16 @@ public class DiskSnapshotBuilder {
         container.active(active);
         container.actualSize(actualSize);
         container.alias(alias);
+        container.backup(backup);
+        container.backupMode(backupMode);
         container.bootable(bootable);
         container.comment(comment);
         container.contentType(contentType);
         container.description(description);
         container.disk(disk);
         container.diskProfile(diskProfile);
+        container.diskSnapshots(diskSnapshots);
+        container.externalDisk(externalDisk);
         container.format(format);
         container.href(href);
         container.id(id);
@@ -730,6 +810,7 @@ public class DiskSnapshotBuilder {
         container.lunStorage(lunStorage);
         container.name(name);
         container.openstackVolumeType(openstackVolumeType);
+        container.parent(parent);
         container.permissions(permissions);
         container.propagateErrors(propagateErrors);
         container.provisionedSize(provisionedSize);
