@@ -27,6 +27,7 @@ import org.ovirt.engine.sdk4.types.Image;
 import org.ovirt.engine.sdk4.types.ImageTransfer;
 import org.ovirt.engine.sdk4.types.ImageTransferDirection;
 import org.ovirt.engine.sdk4.types.ImageTransferPhase;
+import org.ovirt.engine.sdk4.types.ImageTransferTimeoutPolicy;
 
 public class ImageTransferContainer extends IdentifiedContainer implements ImageTransfer {
     private Boolean active;
@@ -35,7 +36,8 @@ public class ImageTransferContainer extends IdentifiedContainer implements Image
     private BigInteger inactivityTimeout;
     private ImageTransferPhase phase;
     private String proxyUrl;
-    private String signedTicket;
+    private Boolean shallow;
+    private ImageTransferTimeoutPolicy timeoutPolicy;
     private String transferUrl;
     private BigInteger transferred;
     private Backup backup;
@@ -136,16 +138,32 @@ public class ImageTransferContainer extends IdentifiedContainer implements Image
         return proxyUrl != null;
     }
     
-    public String signedTicket() {
-        return signedTicket;
+    public boolean shallow() {
+        return shallow;
     }
     
-    public void signedTicket(String newSignedTicket) {
-        signedTicket = newSignedTicket;
+    public void shallow(boolean newShallow) {
+        shallow = Boolean.valueOf(newShallow);
     }
     
-    public boolean signedTicketPresent() {
-        return signedTicket != null;
+    public void shallow(Boolean newShallow) {
+        shallow = newShallow;
+    }
+    
+    public boolean shallowPresent() {
+        return shallow != null;
+    }
+    
+    public ImageTransferTimeoutPolicy timeoutPolicy() {
+        return timeoutPolicy;
+    }
+    
+    public void timeoutPolicy(ImageTransferTimeoutPolicy newTimeoutPolicy) {
+        timeoutPolicy = newTimeoutPolicy;
+    }
+    
+    public boolean timeoutPolicyPresent() {
+        return timeoutPolicy != null;
     }
     
     public String transferUrl() {
