@@ -77,7 +77,9 @@ public class AssignedAffinityLabelServiceImpl extends ServiceImpl implements Ass
                 try (
                   XmlReader reader = new XmlReader(response.getEntity().getContent())
                 ) {
-                    return new GetResponseImpl(XmlAffinityLabelReader.readOne(reader));
+                    GetResponseImpl actionResponse = new GetResponseImpl();
+                    actionResponse.label(XmlAffinityLabelReader.readOne(reader));
+                    return actionResponse;
                 }
                 catch (IOException ex) {
                     throw new Error("Failed to read response", ex);
@@ -88,7 +90,7 @@ public class AssignedAffinityLabelServiceImpl extends ServiceImpl implements Ass
             }
             else {
                 checkFault(response);
-                return new GetResponseImpl(null);
+                return new GetResponseImpl();
             }
         }
         
@@ -97,7 +99,7 @@ public class AssignedAffinityLabelServiceImpl extends ServiceImpl implements Ass
     private class GetResponseImpl implements GetResponse {
         private AffinityLabel label;
         
-        public GetResponseImpl(AffinityLabel label) {
+        public void label(AffinityLabel label) {
             this.label = label;
         }
         
