@@ -48,6 +48,12 @@ public class DiskSnapshotsServiceImpl extends ServiceImpl implements DiskSnapsho
             return this;
         }
         
+        private Boolean includeActive;
+        public ListRequest includeActive(Boolean includeActive) {
+            this.includeActive = includeActive;
+            return this;
+        }
+        
         private BigInteger max;
         public ListRequest max(BigInteger max) {
             this.max = max;
@@ -71,6 +77,9 @@ public class DiskSnapshotsServiceImpl extends ServiceImpl implements DiskSnapsho
                 if (follow != null) {
                     uriBuilder.addParameter("follow", XmlWriter.renderString(follow));
                 }
+                if (includeActive != null) {
+                    uriBuilder.addParameter("include_active", XmlWriter.renderBoolean(includeActive));
+                }
                 if (max != null) {
                     uriBuilder.addParameter("max", XmlWriter.renderInteger(max));
                 }
