@@ -76,7 +76,9 @@ public class SnapshotNicServiceImpl extends ServiceImpl implements SnapshotNicSe
                 try (
                   XmlReader reader = new XmlReader(response.getEntity().getContent())
                 ) {
-                    return new GetResponseImpl(XmlNicReader.readOne(reader));
+                    GetResponseImpl actionResponse = new GetResponseImpl();
+                    actionResponse.nic(XmlNicReader.readOne(reader));
+                    return actionResponse;
                 }
                 catch (IOException ex) {
                     throw new Error("Failed to read response", ex);
@@ -87,7 +89,7 @@ public class SnapshotNicServiceImpl extends ServiceImpl implements SnapshotNicSe
             }
             else {
                 checkFault(response);
-                return new GetResponseImpl(null);
+                return new GetResponseImpl();
             }
         }
         
@@ -96,7 +98,7 @@ public class SnapshotNicServiceImpl extends ServiceImpl implements SnapshotNicSe
     private class GetResponseImpl implements GetResponse {
         private Nic nic;
         
-        public GetResponseImpl(Nic nic) {
+        public void nic(Nic nic) {
             this.nic = nic;
         }
         
