@@ -42,6 +42,12 @@ public class XmlDiskSnapshotWriter {
         if (object.aliasPresent()) {
             writer.writeElement("alias", object.alias());
         }
+        if (object.backupPresent()) {
+            XmlDiskBackupWriter.writeOne(object.backup(), "backup", writer);
+        }
+        if (object.backupModePresent()) {
+            XmlDiskBackupModeWriter.writeOne(object.backupMode(), "backup_mode", writer);
+        }
         if (object.bootablePresent()) {
             writer.writeBoolean("bootable", object.bootable());
         }
@@ -60,6 +66,12 @@ public class XmlDiskSnapshotWriter {
         if (object.diskProfilePresent()) {
             XmlDiskProfileWriter.writeOne(object.diskProfile(), "disk_profile", writer);
         }
+        if (object.diskSnapshotsPresent()) {
+            XmlDiskSnapshotWriter.writeMany(object.diskSnapshots().iterator(), "disk_snapshot", "disk_snapshots", writer);
+        }
+        if (object.externalDiskPresent()) {
+            writer.writeElement("external_disk", object.externalDisk());
+        }
         if (object.formatPresent()) {
             XmlDiskFormatWriter.writeOne(object.format(), "format", writer);
         }
@@ -87,6 +99,9 @@ public class XmlDiskSnapshotWriter {
         if (object.openstackVolumeTypePresent()) {
             XmlOpenStackVolumeTypeWriter.writeOne(object.openstackVolumeType(), "openstack_volume_type", writer);
         }
+        if (object.parentPresent()) {
+            XmlDiskSnapshotWriter.writeOne(object.parent(), "parent", writer);
+        }
         if (object.permissionsPresent()) {
             XmlPermissionWriter.writeMany(object.permissions().iterator(), "permission", "permissions", writer);
         }
